@@ -42,8 +42,8 @@ static gboolean sensors_applet_fill(MatePanelApplet *applet,
     return retval;
 }
 
-MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("SensorsAppletFactory",
-                                       PANEL_TYPE_APPLET,
-                                       "SensorsApplet",
-                                       sensors_applet_fill,
-                                       NULL);
+PANEL_APPLET_FACTORY ("SensorsAppletFactory",
+                      PANEL_TYPE_APPLET,
+                      "SensorsApplet",
+                      sensors_applet_fill,
+                      NULL);
